@@ -9,12 +9,15 @@ $LOAD_PATH.unshift(File.join(test_dir))
 
 require "tomoe-spec-utils"
 
-n = 10
+n = 3
 Benchmark.bmbm do |x|
-  TomoeSpecUtils::Config.dictionaries.sort.each do |dictionary|
-    x.report(File.basename(dictionary)) do
-      n.times {Tomoe::Dict.new("xml", dictionary, false)}
-    end
-    GC.start
+  dictionary = TomoeSpecUtils::Path.dictionary
+  x.report(File.basename(dictionary)) do
+    n.times {Tomoe::DictXML.new("filename" => dictionary,
+                                "editable" => false)}
+  end
+
+  x.report("Unihan") do
+    n.times {Tomoe::DictUnihan.new}
   end
 end
