@@ -17,7 +17,7 @@
  *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  *  Boston, MA  02111-1307  USA
  *
- *  $Id: glib-utils.c,v 1.1 2006/11/27 08:52:01 kous Exp $
+ *  $Id: glib-utils.c,v 1.5 2006/12/25 02:41:48 kous Exp $
  */
 
 #include <glib.h>
@@ -28,10 +28,11 @@ g_ptr_array_foreach_reverse (GPtrArray *array,
                              GFunc      func,
                              gpointer   user_data)
 {
-    guint i;
+    gint i;
 
-    for (i = array->len - 1; i; i--) {
-        func (g_ptr_array_index (array, i), user_data);
+    i = array->len - 1;
+    while (i >= 0) {
+        func (g_ptr_array_index (array, i--), user_data);
     }
 }
 
